import React, { useState, useEffect } from "react";
import { Button } from "@/components/ui/button";
import { Menu, X, Search, ShoppingCart } from "lucide-react";
import { NavigationMenu, NavigationMenuContent, NavigationMenuItem, NavigationMenuLink, NavigationMenuList, NavigationMenuTrigger } from "@/components/ui/navigation-menu";
import { useIsMobile } from "@/hooks/use-mobile";
import { Link } from "react-router-dom";
const Navbar: React.FC = () => {
  const [isScrolled, setIsScrolled] = useState(false);
  const [isMobileMenuOpen, setIsMobileMenuOpen] = useState(false);
  const isMobile = useIsMobile();
  useEffect(() => {
    const handleScroll = () => {
      if (window.scrollY > 50) {
        setIsScrolled(true);
      } else {
        setIsScrolled(false);
      }
    };
    window.addEventListener('scroll', handleScroll);
    return () => {
      window.removeEventListener('scroll', handleScroll);
    };
  }, []);

  // Fixed scroll to sections function
  const scrollToSection = (sectionId: string) => {
    const element = document.getElementById(sectionId);
    if (element) {
      element.scrollIntoView({
        behavior: "smooth"
      });
      setIsMobileMenuOpen(false);
    }
  };
  return <header className={`fixed top-0 left-0 right-0 z-50 transition-all duration-300 ${isScrolled ? 'py-2 backdrop-blur-lg bg-white/95 shadow-md' : 'py-2 bg-white'}`}>
      <div className="container mx-auto px-4 md:px-6">
        <div className="flex items-center justify-between">
          {/* Left side - Brand Logo on desktop, Menu icon on mobile */}
          <div className="flex items-center">
            {isMobile && <button onClick={() => setIsMobileMenuOpen(!isMobileMenuOpen)} className="mr-3 text-gray-700 hover:text-[#ff5b9d] transition-colors" aria-label="Toggle menu">
                {isMobileMenuOpen ? <X className="h-6 w-6" /> : <Menu className="h-6 w-6" />}
              </button>}
            
            {/* Brand Logo - centered on mobile */}
            <div className={`flex ${isMobile ? 'absolute left-1/2 transform -translate-x-1/2' : ''}`}>
              <Link to="/" className="flex items-center space-x-1">
                <img src="/lovable-uploads/7bc16ec8-33a0-4448-9407-fbf3d34cd0fb.png" alt="Aamras Logo" className="h-8 md:h-10 w-auto object-fill" />
              </Link>
            </div>
          </div>
          
          {/* Desktop Navigation - Hidden on Mobile */}
          <nav className="hidden md:flex items-center space-x-8">
            <a onClick={() => scrollToSection('about')} className="text-gray-700 hover:text-[#ff5b9d] transition-colors font-medium cursor-pointer">
              About
            </a>
            <a onClick={() => scrollToSection('collections')} className="text-gray-700 hover:text-[#ff5b9d] transition-colors font-medium cursor-pointer">
              Collections
            </a>
            
          </nav>
          
          {/* Right side - Search and Cart */}
          <div className="flex items-center space-x-4">
            <button className="text-gray-700 hover:text-[#ff5b9d] transition-colors" aria-label="Search">
              
            </button>
            <button className="text-gray-700 hover:text-[#ff5b9d] transition-colors" aria-label="Shopping cart">
              
            </button>
          </div>
        </div>

        {/* Mobile menu */}
        {isMobileMenuOpen && <div className="mt-4 py-4 bg-white rounded-xl shadow-xl animate-fade-in backdrop-blur-lg md:hidden">
            <div className="flex flex-col space-y-4 px-6">
              <a onClick={() => {
            window.scrollTo({
              top: 0,
              behavior: 'smooth'
            });
            setIsMobileMenuOpen(false);
          }} className="text-gray-700 hover:text-[#ff5b9d] transition-colors py-3 border-b border-gray-100 cursor-pointer">
                Home
              </a>
              <a onClick={() => scrollToSection('collections')} className="text-gray-700 hover:text-[#ff5b9d] transition-colors py-3 border-b border-gray-100 cursor-pointer">
                Collections
              </a>
              <a onClick={() => scrollToSection('about')} className="text-gray-700 hover:text-[#ff5b9d] transition-colors py-3 border-b border-gray-100 cursor-pointer">
                About
              </a>
              
              <Button onClick={() => {
            window.open("https://wa.me/919327431897", "_blank");
            setIsMobileMenuOpen(false);
          }} className="text-white w-full py-6 rounded-lg bg-red-600 hover:bg-red-500">
                Wholesale Inquiry
              </Button>
            </div>
          </div>}
      </div>
    </header>;
};
export default Navbar;